Crate guilded_rs
source ·Modules
- This module contains the main event enum and also contains
the event structs and the payloads - This contains all of the models that are required for sending data to guilded
Structs
- Main struct of the library
- The Task for the task pool